==> DO.db_2.1.0.zip: DO.db/doc/DO.db.R <==
###################################################
### chunk number 1: 
###################################################
#line 47 "C:/DOCUME~1/BIOCBU~2/LOCALS~1/Temp/3/RtmpZBDZyW/R.INSTALL55d87f66/DO.db/inst/doc/DO.db.Rnw"
library(DO.db)
help(DO.db)


###################################################
### chunk number 2: 
###################################################
#line 57 "C:/DOCUME~1/BIOCBU~2/LOCALS~1/Temp/3/RtmpZBDZyW/R.INSTALL55d87f66/DO.db/inst/doc/DO.db.Rnw"
FirstTenDOBimap <- DOTERM[1:10] ##grab thet ten
class(FirstTenDOBimap)
xx <- as.list(FirstTenDOBimap)
DOID(xx[[2]])
        Term(xx[[2]])
        Synonym(xx[[2]])
        Secondary(xx[[2]])


###################################################
### chunk number 3: 
###################################################
#line 81 "C:/DOCUME~1/BIOCBU~2/LOCALS~1/Temp/3/RtmpZBDZyW/R.INSTALL55d87f66/DO.db/inst/doc/DO.db.Rnw"
xx <- as.list(DOANCESTOR)
# Remove DO IDs that do not have any ancestor
xx <- xx[!is.na(xx)] 
# Display the first 4 DOID's ancestor
xx[1:4]


###################################################
### chunk number 4: 
###################################################
#line 97 "C:/DOCUME~1/BIOCBU~2/LOCALS~1/Temp/3/RtmpZBDZyW/R.INSTALL55d87f66/DO.db/inst/doc/DO.db.Rnw"
xx <- as.list(DOPARENTS)
# Remove DO IDs that do not have any ancestor
xx <- xx[!is.na(xx)] 
# Display the first 4 DOID's ancestor
xx[1:4]


###################################################
### chunk number 5: 
###################################################
#line 116 "C:/DOCUME~1/BIOCBU~2/LOCALS~1/Temp/3/RtmpZBDZyW/R.INSTALL55d87f66/DO.db/inst/doc/DO.db.Rnw"
xx <- as.list(DOOFFSPRING)
# Remove DO IDs that do not have any ancestor
xx <- xx[!is.na(xx)] 
# Display the first 4 DOID's ancestor
xx[1]


###################################################
### chunk number 6: 
###################################################
#line 134 "C:/DOCUME~1/BIOCBU~2/LOCALS~1/Temp/3/RtmpZBDZyW/R.INSTALL55d87f66/DO.db/inst/doc/DO.db.Rnw"
xx <- as.list(DOCHILDREN)
# Remove DO IDs that do not have any ancestor
xx <- xx[!is.na(xx)] 
# Display the first 4 DOID's ancestor
xx[1]


###################################################
### chunk number 7: 
###################################################
#line 146 "C:/DOCUME~1/BIOCBU~2/LOCALS~1/Temp/3/RtmpZBDZyW/R.INSTALL55d87f66/DO.db/inst/doc/DO.db.Rnw"
DO_dbschema()


###################################################
### chunk number 8: 
###################################################
#line 152 "C:/DOCUME~1/BIOCBU~2/LOCALS~1/Temp/3/RtmpZBDZyW/R.INSTALL55d87f66/DO.db/inst/doc/DO.db.Rnw"
DOMAPCOUNTS

==> DO.db_2.2.zip: DO.db/doc/DO.db.R <==
###################################################
### chunk number 1: 
###################################################
#line 47 "DO.db.Rnw"
library(DO.db)
help(DO.db)


###################################################
### chunk number 2: 
###################################################
#line 57 "DO.db.Rnw"
FirstTenDOBimap <- DOTERM[1:10] ##grab thet ten
class(FirstTenDOBimap)
xx <- as.list(FirstTenDOBimap)
DOID(xx[[2]])
        Term(xx[[2]])
        Synonym(xx[[2]])
        Secondary(xx[[2]])


###################################################
### chunk number 3: 
###################################################
#line 81 "DO.db.Rnw"
xx <- as.list(DOANCESTOR)
# Remove DO IDs that do not have any ancestor
xx <- xx[!is.na(xx)] 
# Display the first 4 DOID's ancestor
xx[1:4]


###################################################
### chunk number 4: 
###################################################
#line 97 "DO.db.Rnw"
xx <- as.list(DOPARENTS)
# Remove DO IDs that do not have any ancestor
xx <- xx[!is.na(xx)] 
# Display the first 4 DOID's ancestor
xx[1:4]


###################################################
### chunk number 5: 
###################################################
#line 116 "DO.db.Rnw"
xx <- as.list(DOOFFSPRING)
# Remove DO IDs that do not have any ancestor
xx <- xx[!is.na(xx)] 
# Display the first 4 DOID's ancestor
xx[1]


###################################################
### chunk number 6: 
###################################################
#line 134 "DO.db.Rnw"
xx <- as.list(DOCHILDREN)
# Remove DO IDs that do not have any ancestor
xx <- xx[!is.na(xx)] 
# Display the first 4 DOID's ancestor
xx[1]


###################################################
### chunk number 7: 
###################################################
#line 146 "DO.db.Rnw"
DO_dbschema()


###################################################
### chunk number 8: 
###################################################
#line 152 "DO.db.Rnw"
DOMAPCOUNTS
